# LibreTranslate Trademark Guidelines

LibreTranslate is an open source organization. Because we make our code available to download and modify, proper use of our trademarks is essential to inform users whether or not LibreTranslate stands behind a product or service. When using LibreTranslate trademarks (including some product names that are part of our organization) you must comply with these LibreTranslate Trademark Guidelines.

Some of our trademark names include:

 * LibreTranslate

Some of our trademark logos include:

 ![LibreTranslate](https://avatars.githubusercontent.com/u/77352747?s=200&v=4)

However, this is not a complete list of our names, logos, and brand features, all of which are subject to these guidelines.

If you want to report misuse of an LibreTranslate trademark, please contact us via https://uav4geo.com/contact

## When do I need specific permission to use an LibreTranslate trademark?

Noting that LibreTranslate software combined with, or integrated into, any other software program, including but not limited to automation software for offering LibreTranslate as a cloud service or orchestration software for offering LibreTranslate in containers is considered "modified" LibreTranslate software, you may do the following without receiving specific permission from LibreTranslate (or its affiliates):

 * Use LibreTranslate wordmarks and/or logos in unmodified versions of LibreTranslate programs, products, services and technologies.
 * Use LibreTranslate wordmarks in text to truthfully refer to and/or link to unmodified LibreTranslate programs, products, services and technologies.
 * Use LibreTranslate logos in visuals to truthfully refer to and/or to link to the applicable programs, products, services and technologies hosted on LibreTranslate servers.
 * Use LibreTranslate wordmarks to explain that your software is based on LibreTranslate's open source code, or is compatible with LibreTranslate's software.
 * Describe a social media account, page, or community in accordance with the [Social Media Guidelines](#social-media-guidelines).

All other uses of an LibreTranslate trademark require our prior written permission. This includes any use of a LibreTranslate trademark in a domain name. Contact us at https://uav4geo.com/contact for more information.

## When allowed, how should I use an LibreTranslate trademark?

### General Guidelines

#### Do:

 * Use the LibreTranslate trademark exactly as shown in the list above.
 * Use LibreTranslate wordmarks only as an adjective, never as a noun or verb. Do not use them in plural or possessive forms. Instead, use the generic term for the LibreTranslate product or service following the trademark, for example: LibreTranslate translation software.

#### Don't:

 * Don't use LibreTranslate trademarks in the name of your business, product, service, app, domain name, publication, or other offering.
 * Don't use marks, logos, company names, slogans, domain names, or designs that are confusingly similar to LibreTranslate trademarks.
 * Don't use LibreTranslate trademarks in a way that incorrectly implies affiliation with, or sponsorship, endorsement, or approval by LibreTranslate of your products or services.
 * Don't display LibreTranslate trademarks more prominently than your product, service, or company name.
 * Don't use LibreTranslate trademarks on merchandise for sale (e.g., selling t-shirts, mugs, etc.)
 * Don't use LibreTranslate trademarks for any other form of commercial use (e.g. offering technical support services), unless such use is limited to a truthful and descriptive reference (e.g. Independent technical support for LibreTranslate's software).
 * Don't modify LibreTranslate's trademarks, abbreviate them, or combine them with any other symbols, words, or images, or incorporate them into a tagline or slogan.

 ### Social Media Guidelines

In addition to the General Guidelines above, the name and handle of your social media account and any and all pages cannot begin with an LibreTranslate trademark. In addition, LibreTranslate logos cannot be used in a way that might suggest affiliation with LibreTranslate, including, but not limited to, the account, profile, or header images. The only exception to these requirements is if you've received prior permission from LibreTranslate.

For example, you cannot name your account, page, or community "LibreTranslate Representatives" or "LibreTranslate Software". However, it would be acceptable to name your account, page, or community "Fans of LibreTranslate" or "Information about LibreTranslate Software" as long as you do not use the LibreTranslate trademarks or LibreTranslate logos or otherwise suggest any affiliation with LibreTranslate.

### Open Source Project Guidelines

The specific license for each of LibreTranslate's software products and code says what you can and cannot do with the code itself but does not give permission to use LibreTranslate's trademarks. If you choose to build on or modify LibreTranslate's open source code for your own project,

#### You Must:

 * Follow the terms of the Open Source License(s) for LibreTranslate software products and code.
 * Choose branding, logos, and trademarks that denotes your own unique identity so as to clearly signal to users that there is no affiliation with or endorsement by LibreTranslate.
 * Follow the General Guidelines, above.

#### You Must NOT:

* Use any LibreTranslate trademark in connection with the user-facing name or branding of your project.
 * Use any LibreTranslate trademark or any part of any LibreTranslate trademark to incorrectly suggest or give the impression your software is actually published by, affiliated with, or endorsed by LibreTranslate.

For example, please do not name your project, [Something]-LibreTranslate, or LibreTranslate-[Something]

#### You May:

 * State in words (not using logos or images) that your product "works with" or "is compatible" with certain LibreTranslate software products, if that is true.
 * State in words (not using logos or images) that your project is based on LibreTranslate open source technology, if that is true, as long as you also include a statement that your project is not officially associated with LibreTranslate or its products.

For instance, you may state that your project:

"is proudly built from LibreTranslate's open source software"

as long as you also include the statement equally prominently:

"[Brand Name] and [Product Name] are not officially associated with LibreTranslate or its products."

### LibreTranslate Community Guidelines

Various permissions to use LibreTranslate Trademarks have been provided to various members of the LibreTranslate Community, and these LibreTranslate Trademark Guidelines do not alter any such previously granted permissions.
